Learn R Programming

mtconnectR (version 1.0.0)

clean_reduntant_rows: Removes Redundant Rows in a data frame assuming statefulness

Description

Removes Redundant Rows in a data frame assuming statefulness

Usage

clean_reduntant_rows(df, clean_colname = "value", echo = F)

Arguments

df
Data.frame in timestamp, value1, value2,...
clean_colname
Name of the column to clean as basis
echo
Whether to return messages or not

Examples

Run this code
test_interval =
  data.frame(timestamp = as.POSIXct(c(0.5, 1, 1.008, 1.011), origin = "1970-01-01"),
            x     = c("a", "b", "b", "b"),
             y     = c("e", "e", "e", "f"))
clean_reduntant_rows(test_interval, "x")

Run the code above in your browser using DataLab