Learn R Programming

mtconnectR (version 1.0.0)

getDataItem,MTCCycle,character-method: Get one or more data items from the MTCCycle or MTCDevice using a character pattern

Description

Get one or more data items from the MTCCycle or MTCDevice using a character pattern

Usage

"getDataItem"(.Object, pattern)

Arguments

.Object
Object of MTCCycle or MTCDevice Class
pattern
Regex of the pattern by which the data is queried

Examples

Run this code
data("example_mtc_device")
getDataItem(example_mtc_device, "POSIT")

Run the code above in your browser using DataLab