Learn R Programming

mtconnectR (version 0.2.0)

merge,MTCCycle,character-method: Merge on or more data items from the MTCCycle or MTCDevice using a character pattern

Description

Merge on or more data items from the MTCCycle or MTCDevice using a character pattern

Usage

## S3 method for class 'MTCCycle,character':
merge(x, y)

Arguments

x
object of MTCCycle or MTCDevice Class
y
regexp of the pattern by which the merge has to be done

Examples

Run this code
data("example_mtc_device")
merge(example_mtc_device, "POSIT")

Run the code above in your browser using DataLab