Learn R Programming

mtconnectR (version 1.0.0)

merge,MTCCycle,numeric-method: Merge one or more data items from the MTCCycle or MTCDevice using an index

Description

Merge one or more data items from the MTCCycle or MTCDevice using an index

Usage

"merge"(x, y)

Arguments

x
Object of MTCCycle or MTCDevice Class
y
Numeric index/indices of the data items to be merged

Examples

Run this code
data("example_mtc_device")
merge(example_mtc_device, 1)

Run the code above in your browser using DataLab