Learn R Programming

mtconnectR (version 0.2.0)

getDataItem,MTCCycle,character-method: Get one or more data items from the MTCCycle or MTCDevice using a character pattern

Description

Get one or more data items from the MTCCycle or MTCDevice using a character pattern

Usage

## S3 method for class 'MTCCycle,character':
getDataItem(.Object, pattern)

Arguments

.Object
object of MTCCycle or MTCDevice Class
pattern
regexp of the pattern by which the data is queried

Examples

Run this code
data("example_mtc_device")
getDataItem(example_mtc_device, "POSIT")

Run the code above in your browser using DataLab