Learn R Programming

mtconnectR (version 0.2.0)

merge,MTCCycle,numeric-method: Merge on or more data items from the MTCCycle or MTCDevice using an index

Description

Merge on or more data items from the MTCCycle or MTCDevice using an index

Usage

## S3 method for class 'MTCCycle,numeric':
merge(x, y)

Arguments

x
object of MTCCycle or MTCDevice Class
y
numeric indices of the data items to be merged

Examples

Run this code
data("example_mtc_device")
merge(example_mtc_device, 1)

Run the code above in your browser using DataLab